# bpmn-print

Print BPMN workflow for developer readings

## Installation

```
pip install bpmn_print
```

## Usage

```
$ bpmn-print -h
usage: bpmn-print [-h] [-v] [-k] input_folder output_folder

Print BPMN workflow for developer readings

positional arguments:
  input_folder   input folder
  output_folder  output folder

options:
  -h, --help     show this help message and exit
  -v, --version  show program's version number and exit
  -k, --keep     keep PNG files after PDF generation

```

## Links

- https://pypi.org/project/bpmn_print/
- https://github.com/siakhooi/bpmn-print
- https://sonarcloud.io/project/overview?id=siakhooi_bpmn-print
- https://qlty.sh/gh/siakhooi/projects/bpmn-print

## Badges

![GitHub](https://img.shields.io/github/license/siakhooi/bpmn-print?logo=github)
![GitHub last commit](https://img.shields.io/github/last-commit/siakhooi/bpmn-print?logo=github)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/siakhooi/bpmn-print?logo=github)
![GitHub issues](https://img.shields.io/github/issues/siakhooi/bpmn-print?logo=github)
![GitHub closed issues](https://img.shields.io/github/issues-closed/siakhooi/bpmn-print?logo=github)
![GitHub pull requests](https://img.shields.io/github/issues-pr-raw/siakhooi/bpmn-print?logo=github)
![GitHub closed pull requests](https://img.shields.io/github/issues-pr-closed-raw/siakhooi/bpmn-print?logo=github)
![GitHub top language](https://img.shields.io/github/languages/top/siakhooi/bpmn-print?logo=github)
![GitHub language count](https://img.shields.io/github/languages/count/siakhooi/bpmn-print?logo=github)
![GitHub repo size](https://img.shields.io/github/repo-size/siakhooi/bpmn-print?logo=github)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/siakhooi/bpmn-print?logo=github)

![Workflow](https://img.shields.io/badge/Workflow-github-purple)
![workflow](https://github.com/siakhooi/bpmn-print/actions/workflows/build.yaml/badge.svg)
![workflow](https://github.com/siakhooi/bpmn-print/actions/workflows/workflow-deployments.yml/badge.svg)

![Release](https://img.shields.io/badge/Release-github-purple)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/siakhooi/bpmn-print?label=GPR%20release&logo=github)
![GitHub all releases](https://img.shields.io/github/downloads/siakhooi/bpmn-print/total?color=33cb56&logo=github)
![GitHub Release Date](https://img.shields.io/github/release-date/siakhooi/bpmn-print?logo=github)

![Quality-Qlty](https://img.shields.io/badge/Quality-Qlty-purple)
[![Maintainability](https://qlty.sh/gh/siakhooi/projects/bpmn-print/maintainability.svg)](https://qlty.sh/gh/siakhooi/projects/bpmn-print)
[![Code Coverage](https://qlty.sh/gh/siakhooi/projects/bpmn-print/coverage.svg)](https://qlty.sh/gh/siakhooi/projects/bpmn-print)

![Quality-Sonar](https://img.shields.io/badge/Quality-SonarCloud-purple)
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=code_smells)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Duplicated Lines (%)](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=duplicated_lines_density)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=bugs)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Technical Debt](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=sqale_index)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=sqale_rating)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=security_rating)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=reliability_rating)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Lines of Code](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=ncloc)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=siakhooi_bpmn-print&metric=coverage)](https://sonarcloud.io/summary/new_code?id=siakhooi_bpmn-print)
![Sonar Violations (short format)](https://img.shields.io/sonar/violations/siakhooi_bpmn-print?server=https%3A%2F%2Fsonarcloud.io)
![Sonar Violations (short format)](https://img.shields.io/sonar/blocker_violations/siakhooi_bpmn-print?server=https%3A%2F%2Fsonarcloud.io)
![Sonar Violations (short format)](https://img.shields.io/sonar/critical_violations/siakhooi_bpmn-print?server=https%3A%2F%2Fsonarcloud.io)
![Sonar Violations (short format)](https://img.shields.io/sonar/major_violations/siakhooi_bpmn-print?server=https%3A%2F%2Fsonarcloud.io)
![Sonar Violations (short format)](https://img.shields.io/sonar/minor_violations/siakhooi_bpmn-print?server=https%3A%2F%2Fsonarcloud.io)
![Sonar Violations (short format)](https://img.shields.io/sonar/info_violations/siakhooi_bpmn-print?server=https%3A%2F%2Fsonarcloud.io)
![Sonar Violations (long format)](https://img.shields.io/sonar/violations/siakhooi_bpmn-print?format=long&server=http%3A%2F%2Fsonarcloud.io)

[![Wise](https://img.shields.io/badge/Funding-Wise-33cb56.svg?logo=wise)](https://wise.com/pay/me/siakn3)
![visitors](https://hit-tztugwlsja-uc.a.run.app/?outputtype=badge&counter=ghmd-bpmn-print)
